#define XERR

#include "guncat.ih"

Guncat::Guncat()
:
    d_options(Options::instance()),

    d_gpgCommand(d_options.gpgCommand()),
    d_pgpRanges(d_options.pgpRanges()),
    d_reduceHeaders(d_options.reduceHeaders()),
    d_decryptor(d_gpgHandler)
{}
